import { BrowserModule } from '@angular/platform-browser';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { NgModule } from '@angular/core';

import { TranslateModule, TranslateLoader } from '@ngx-translate/core';

import { CommonsUIModule } from '@overflow/commons/ui/commons-ui.module';

import {
  PerfectScrollbarModule,
  PERFECT_SCROLLBAR_CONFIG,
  PerfectScrollbarConfigInterface,
} from 'ngx-perfect-scrollbar';


import { AppRoutingModule } from './app-routing.module';
import { AppStoreModule } from './app-store.module';

import { AppComponent } from './app.component';
import { COMPONENTS } from './component';
import { PAGES } from './pages';

import { SERVICES } from './service';
import { I18nService } from './service/i18n.service';

const DEFAULT_PERFECT_SCROLLBAR_CONFIG: PerfectScrollbarConfigInterface = {
  suppressScrollX: true
};


@NgModule({
  imports: [
    BrowserModule,
    BrowserAnimationsModule,
    TranslateModule.forRoot({
      loader: {
        provide: TranslateLoader,
        useExisting: I18nService,
      }
    }),
    PerfectScrollbarModule,

    CommonsUIModule,

    AppRoutingModule,
    AppStoreModule,
  ],
  declarations: [
    AppComponent,
    ...COMPONENTS,
    ...PAGES,
  ],
  providers: [
    ...SERVICES,
    {
      provide: PERFECT_SCROLLBAR_CONFIG,
      useValue: DEFAULT_PERFECT_SCROLLBAR_CONFIG
    }
  ],
  bootstrap: [AppComponent]
})
export class AppModule { }
