import { Component, Input, OnChanges, SimpleChanges, ViewChildren, QueryList } from '@angular/core';

import { of } from 'rxjs';
import { map, catchError, take } from 'rxjs/operators';

import { Host } from '@overflow/model/discovery';
import { PingResult } from '@overflow/model/ping';

import { AutoHeightDirective } from '@overflow/commons/ui/directive/auto-height.directive';
import { PingService } from '../../../service/ping.service';
import { PingOption } from '@overflow/model/config/ping';

@Component({
  selector: 'app-infra-detail-host',
  templateUrl: './host.component.html',
  styleUrls: ['./host.component.scss'],
})
export class HostComponent implements OnChanges {
  @Input() host: Host;

  @ViewChildren(AutoHeightDirective) autoHeightDirectives: QueryList<AutoHeightDirective>;


  pingWaiting: boolean;

  count: number;
  interval: number;
  deadline: number;

  pingResult: PingResult;
  pingResultRaw: string;


  constructor(
    private pingService: PingService,
  ) {
    this.pingWaiting = false;
    this.count = 5;
    this.interval = 1;
    this.deadline = 1;
  }

  ngOnChanges(simpleChanges: SimpleChanges): void {
    this.pingResult = null;
  }


  doPing() {
    this.pingWaiting = true;

    const option: PingOption = {
      count: this.count,
      interval: this.interval,
      deadline: this.deadline,
    };

    this.pingService.pingHost(this.host, option)
      .pipe(
        map((pingResult: PingResult) => {
          if (pingResult) {
            this.pingResult = pingResult;
            this.pingResultRaw = pingResult.raw.join('\r\n');
          }
          this.pingWaiting = false;
        }),
        catchError(error => {
          console.log(error);
          alert('An error has occurred.');
          this.pingWaiting = false;
          return of();
        }),
        take(1)
      )
      .subscribe();
  }

  onTabViewChange($event) {
    const index = String($event.index);
    this.autoHeightDirectives.map(item => {
      if (item.key === index) {
        item.forceCalculate();
      }
    });
  }

}
