import { Component, OnInit, AfterContentInit, OnDestroy, } from '@angular/core';
import { Store, select } from '@ngrx/store';
import { take } from 'rxjs/operators';

import * as AppStore from '../../store';
import { InfraDisplayType } from '../../core/type';
import { Message } from 'primeng/primeng';

const { saveSvgAsPng, svgAsDataUri, download } = require('save-svg-as-png');

@Component({
  selector: 'app-menu-export-svg',
  templateUrl: './export-svg.component.html',
  styleUrls: ['./export-svg.component.scss'],
})
export class ExportSVGComponent implements OnInit, AfterContentInit, OnDestroy {
  msgs: Message[] = [];

  constructor(
    private store: Store<any>,
  ) {
  }

  ngOnInit(): void {
  }

  ngAfterContentInit(): void {

  }

  ngOnDestroy(): void {

  }

  export() {
    const __this = this;
    this.store.pipe(
      take(1),
      select((state) => {
        const infraDisplayType = AppStore.InfraSelector.InfraSelector.selectInfraDisplayType(state);
        const infraDisplayElementRef = AppStore.InfraSelector.InfraSelector.selectInfraDisplayElementRef(state);

        if (InfraDisplayType.MAP !== infraDisplayType) {
          this.msgs = [];
          this.msgs.push({
            severity: 'error',
            summary: 'Invalid Display Type',
            detail: 'Export SVG is only supported for Map Display type'
          });
          return;
        }

        svgAsDataUri(infraDisplayElementRef.nativeElement, { backgroundColor: '#ffffff' }, function (uri) {
          download('diagram.svg', uri);
        });
      }),
    ).subscribe();
  }
}
